@@ -1,6 +1,12 @@
 package Mojolicious::Plugin::Minion::Overview::Controller::Dashboard;
 use Mojo::Base 'Mojolicious::Controller';
 
+=head2 search
+
+Show dashboard metrics
+
+=cut
+
 sub search {
     my $self = shift;
 
